@@ -1,9 +1,10 @@
 import json
 import os
 import subprocess as sp
-import traceback
-from pathlib import Path
 import sys
+import traceback
+from functools import partial
+from pathlib import Path
 
 from batchx import bx
 
@@ -16,8 +17,6 @@ from .error import (
 )
 from .io import save_json
 
-from functools import partial
-
 
 def check_for_custom_exception(
     stderr: str,
@@ -46,14 +45,14 @@ def check_for_acceptable_exit_code(
     raise_error: bool = False,
 ):
     debug_print(
-        "{} Exit code".format(identifier),
+        "{} | Exit code".format(identifier),
         exit_code,
         verbose=verbose,
         long=False,
     )
 
     if exit_code not in acceptable_exit_codes:
-        error_message = """
+        msg = """
         Exit code {c} not in acceptable exit codes {ac}.
         StdErr:
             {error_msg}
@@ -63,8 +62,13 @@ def check_for_acceptable_exit_code(
             ac=acceptable_exit_codes,
         )
         if raise_error:
-            raise ValueError(error_message) from None
+            raise ValueError(msg) from None
         else:
+            debug_print(
+                "Inacceptable exit code error message",
+                msg,
+                verbose=verbose,
+            )
             return exit_code
     else:
         return exit_code
@@ -218,6 +222,7 @@ def run_bx_job(
         handle_unknown_exception(exception=e, identifier=identifier, reraise=reraise)
 
     exit_code = inspect_bx_response(
+        response=response,
         identifier=identifier,
         acceptable_exit_codes=acceptable_exit_codes,
         inacceptable_exit_code_raise_error=inacceptable_exit_code_raise_error,
